@@ -109,7 +109,7 @@ class distfit():
     >>> dist.plot()
     """
 
-    def __init__(self, method='parametric', alpha=0.05, multtest='fdr_bh', bins=50, bound='both', distr='popular', stats='RSS', smooth=None, n_perm=10000, todf=False, weighted=True, f=1.5):
+    def __init__(self, method='parametric', alpha=0.05, multtest='fdr_bh', bins=50, bound='both', distr='popular', stats='RSS', smooth=None, n_perm=10000, todf=False, weighted=True, f=1.5, mhist='numpy'):
         """Initialize distfit with user-defined parameters."""
         if (alpha is None): alpha=1
         self.method = method
@@ -124,6 +124,7 @@ class distfit():
         self.stats = stats
         self.f = f  # Only for discrete
         self.weighted = weighted  # Only for discrete
+        self.mhist = mhist
 
     # Fit
     def fit(self, verbose=3):
@@ -205,7 +206,7 @@ class distfit():
         self.size = len(X)
 
         # Get histogram of original X
-        X_bins, y_obs = _get_hist_params(X, self.bins)
+        X_bins, y_obs = _get_hist_params(X, self.bins, mhist=self.mhist)
         # Smoothing by interpolation
         X_bins, y_obs = smoothline(X_bins, y_obs, window=self.smooth, interpol=1, verbose=verbose)
         self.histdata = (y_obs, X_bins)
@@ -713,9 +714,9 @@ def _plot_quantile(self, title='', figsize=(15, 8), xlim=None, ylim=None, fig=No
             ax.scatter(self.results['y'][idxOUT], np.zeros(sum(idxOUT)), color='r', marker='x', alpha=0.8, linewidth=1.5, label='Inside boundaries')
 
     # Limit axis
-    if xlim is not None:        
+    if xlim is not None:
         ax.set_xlim(xlim[0], xlim[1])
-    if ylim is not None:        
+    if ylim is not None:
         ax.set_ylim(ylim[0], ylim[1])
 
     ax.grid(True)
@@ -777,15 +778,15 @@ def _plot_parametric(self, title='', figsize=(10, 8), xlim=None, ylim=None, fig=
 
     # Make text for plot
     param_names = (best_dist.shapes + ', loc, scale').split(', ') if best_dist.shapes else ['loc', 'scale']
-    param_str = ', '.join(['{}={:0.2f}'.format(k, v) for k, v in zip(param_names, best_fit_param)])
-    ax.set_title('%s\n%s\n%s' %(Param['title'], best_fit_name, param_str))
+    param_str = ', '.join(['{}={:g}'.format(k, v) for k, v in zip(param_names, best_fit_param)])
+    ax.set_title('%s\n%s\n%s' %(Param['title'], best_fit_name, self.stats + '(' + param_str + ')'))
     ax.set_xlabel('Values')
     ax.set_ylabel('Frequency')
 
     # Limit axis
-    if Param['xlim'] is not None:        
+    if Param['xlim'] is not None:
         ax.set_xlim(Param['xlim'][0], Param['xlim'][1])
-    if Param['ylim'] is not None:        
+    if Param['ylim'] is not None:
         ax.set_ylim(Param['ylim'][0], Param['ylim'][1])
 
     # Add significant hits as line into the plot. This data is dervived from dist.proba_parametric
@@ -892,7 +893,7 @@ def _get_hist_params(X, bins, mhist='numpy'):
         snsout = sns.distplot(X, bins=bins, norm_hist=False).get_lines()[0].get_data()
         histvals = snsout[1]
         binedges = snsout[0]
-        binedges = np.append(binedges, 10**-6)
+        # binedges = np.append(binedges, 10**-6)
 
     return(binedges, histvals)
 
@@ -909,7 +910,7 @@ def _compute_score_distribution(data, X, y_obs, DISTRIBUTIONS, stats, verbose=3)
 
     # Estimate distribution parameters
     for i, distribution in enumerate(DISTRIBUTIONS):
-        logLik = 0
+        logLik = np.nan
 
         # Fit the distribution. However this can result in an error so therefore you need to try-except
         try:
@@ -928,17 +929,8 @@ def _compute_score_distribution(data, X, y_obs, DISTRIBUTIONS, stats, verbose=3)
 
                 # Calculate fitted PDF and error with fit in distribution
                 pdf = distribution.pdf(X, loc=loc, scale=scale, *arg)
-                # Compute RSS
-                if stats=='RSS':
-                    score = np.sum(np.power(y_obs - pdf, 2.0))
-                if stats=='wasserstein':
-                    score = st.wasserstein_distance(y_obs, pdf)
-                if stats=='energy':
-                    score = st.energy_distance(y_obs, pdf)
-                if stats=='ks':
-                    score = -np.log10(st.ks_2samp(y_obs, pdf)[1])
-
-                logLik = np.nan
+                # Compute score based on fit
+                score = _compute_fit_score(stats, y_obs, pdf)
 
                 # Store results
                 df.values[i, 0] = distribution.name
@@ -962,7 +954,7 @@ def _compute_score_distribution(data, X, y_obs, DISTRIBUTIONS, stats, verbose=3)
 
             if verbose>=3:
                 spaces_1 = ' ' * (max_name_len - len(distribution.name))
-                scores = ('[%s: %.7f] [loc=%.3f scale=%.3f]' %(stats, score, loc, scale))
+                scores = ('[%s: %g] [loc=%.3f scale=%.3f]' %(stats, score, loc, scale))
                 time_spent = time.time() - start_time
                 print("[distfit] >[%s%s] [%.4s sec] %s" %(distribution.name, spaces_1, time_spent, scores))
 
@@ -978,6 +970,23 @@ def _compute_score_distribution(data, X, y_obs, DISTRIBUTIONS, stats, verbose=3)
     return(df, model)
 
 
+# %% Compute fit score
+def _compute_fit_score(stats, y_obs, pdf):
+    if stats=='RSS':
+        score = np.sum(np.power(y_obs - pdf, 2.0))
+        # score = (((y_obs - pdf) / sigmas)**2).sum()
+    elif stats=='wasserstein':
+        score = st.wasserstein_distance(y_obs, pdf)
+    elif stats=='energy':
+        score = st.energy_distance(y_obs, pdf)
+    elif stats=='ks':
+        score = -np.log10(st.ks_2samp(y_obs, pdf)[1])
+        # score = -np.log10(st.kstest(y_obs, pdf)[1])
+    else:
+        raise Exception('[%] statistic not implemented.', stats)
+    return score
+
+
 # %% Determine confidence intervals on the best fitting distribution
 def _compute_cii(self, model, verbose=3):
     if verbose>=3: print("[distfit] >Compute confidence interval [%s]" %(self.method))
@@ -1223,16 +1232,8 @@ def transform_binom(hist, plot=True, weighted=True, f=1.5, stats='RSS', verbose=
         # Determine RSS
         p = fitparams[0]
         pdf = BinomPMF(nval)(Xdata, p)
-
-        if stats=='RSS':
-            score = (((y_obs - pdf) / sigmas)**2).sum()
-        if stats=='wasserstein':
-            score = st.wasserstein_distance(y_obs, pdf)
-        if stats=='energy':
-            score = st.energy_distance(y_obs, pdf)
-        if stats=='ks':
-            score = -np.log10(st.ks_2samp(y_obs, pdf)[1])
-
+        # Compute fit score
+        score = _compute_fit_score(stats, y_obs, pdf)
         # Store
         pvals[nval - nmin] = p
         scores[nval - nmin] = score
@@ -1328,7 +1329,7 @@ def plot_binom(self, title='', figsize=(10, 8), xlim=None, ylim=None, verbose=3)
         ax[0].axvline(x=model['CII_max_alpha'], ymin=0, ymax=1, linewidth=1.3, color='r', linestyle='dashed', label=label)
 
     # Make text for plot
-    param_str = ', '.join(['{}={:0.2g}'.format(k, v) for k, v in zip(['n', 'p'], best_fit_param)])
+    param_str = ', '.join(['{}={:g}'.format(k, v) for k, v in zip(['n', 'p'], best_fit_param)])
     ax[0].set_title('%s\n%s\n%s' %(Param['title'], best_fit_name, param_str))
 
     # Limit axis
